summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/scheduledtransaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/scheduledtransaction.h')
-rw-r--r--kmymoney2/widgets/scheduledtransaction.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kmymoney2/widgets/scheduledtransaction.h b/kmymoney2/widgets/scheduledtransaction.h
index 836ceee..a1530ec 100644
--- a/kmymoney2/widgets/scheduledtransaction.h
+++ b/kmymoney2/widgets/scheduledtransaction.h
@@ -38,7 +38,7 @@ namespace KMyMoneyRegister {
class StdTransactionScheduled : public StdTransaction
{
public:
- StdTransactionScheduled(Register* parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
+ StdTransactionScheduled(Register* tqparent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
virtual ~StdTransactionScheduled() {}
virtual const char* className(void) { return "StdTransactionScheduled"; }
@@ -55,15 +55,15 @@ public:
* - textRect (area covering the text)
* - color of the pen to do the painting of text and lines
*
* @param painter pointer to the QPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
* @param cellRect ref to QRect object receiving the area information for the cell
* @param textRect ref to QRect object receiving the area information for the text
* @param cg ref to QColorGroup object receiving the color information to be used
* @param brush ref to QBrush object receiveing the brush information to be used
*/
- virtual bool paintRegisterCellSetup(QPainter* painter, int& row, int& col, QRect& cellRect, QRect& textRect, QColorGroup& cg, QBrush& brush);
+ virtual bool paintRegisterCellSetup(TQPainter* painter, int& row, int& col, TQRect& cellRect, TQRect& textRect, TQColorGroup& cg, TQBrush& brush);
bool isSelectable(void) const { return true; }
bool canHaveFocus(void) const { return true; }
@@ -71,9 +71,9 @@ public:
virtual int sortSamePostDate(void) const { return 4; }
-// virtual void paintRegisterGrid(QPainter* painter, int row, int col, const QRect& r, const QColorGroup& cg) const;
+// virtual void paintRegisterGrid(TQPainter* painter, int row, int col, const TQRect& r, const TQColorGroup& cg) const;
-// void registerCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
+// void registerCellText(TQString& txt, int& align, int row, int col, TQPainter* painter = 0);
private:
unsigned int m_drawCounter;
@@ -55,15 +55,15 @@ public:
* - color of the pen to do the painting of text and lines
*
- * @param painter pointer to the QPainter object
+ * @param painter pointer to the TQPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
@@ -55,15 +55,15 @@ public:
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
- * @param cellRect ref to QRect object receiving the area information for the cell
- * @param textRect ref to QRect object receiving the area information for the text
- * @param cg ref to QColorGroup object receiving the color information to be used
- * @param brush ref to QBrush object receiveing the brush information to be used
+ * @param cellRect ref to TQRect object receiving the area information for the cell
+ * @param textRect ref to TQRect object receiving the area information for the text
+ * @param cg ref to TQColorGroup object receiving the color information to be used
+ * @param brush ref to TQBrush object receiveing the brush information to be used
*/